@@ -65,6 +65,9 @@ int desktop_use_shaped_text = 0;
 /* The computed name of the user's desktop directory */
 char *desktop_directory;
 
+/* Time of the last directory reload */
+time_t desktop_dir_modify_time;
+
 /* Layout information:  number of rows/columns for the layout slots, and the
  * array of slots.  Each slot is an integer that specifies the number of icons
  * that belong to that slot.
@@ -202,7 +205,7 @@ auto_pos (int sx, int ex, int sy, int ey, int *slot)
 {
 	int min, min_slot;
 	int x, y;
-	int val;
+	int val = 0;
 	int xinc, yinc;
 	int r, b;
 
@@ -592,14 +595,62 @@ get_drop_grid (gint xpos, gint ypos, gint need_position_list_length, GSList *gri
 			        get_icon_snap_pos (&new_xpos, &new_ypos);
 			}
 	                
-			grid_list = g_slist_append (grid_list, (void *) new_xpos);	      	                                    grid_list = g_slist_append (grid_list, (void *) new_ypos);
+			grid_list = g_slist_append (grid_list, (void *) new_xpos);
+			grid_list = g_slist_append (grid_list, (void *) new_ypos);
 	        }
 	}
 
 	return grid_list;
 
 }
+
+#define NAUTILUS_KEY "<?xml version=\"1.0\"?>\n<nautilus_object nautilus_link=\""
+#define NAUTILUS_MOUNT_KEY "Mount Link\""
+#define NAUTILUS_GENERIC_KEY "Generic Link\""
+#define NAUTILUS_HOME_KEY "Home Link\""
+#define NAUTILUS_TRASH_KEY "Trash Link\""
+
+static gboolean
+should_skip_nautilus_file (char *name)
+{
+	char buffer [256], *full, *p;
+	FILE *f;
+	int n;
+
+	if (strcmp (name, ".nautilus-metafile.xml") == 0)
+		return TRUE;
+
+	if (strcmp (name, "Trash") == 0)
+		return TRUE;
+
+	full = g_concat_dir_and_file (desktop_directory, name);
+	f = fopen (full, "r");
+	g_free (full);
 	
+	if (f == NULL)
+		return FALSE;
+	n = fread (buffer, sizeof (buffer), 1, f);
+	fclose (f);
+
+	if (n < 0)
+		return FALSE;
+
+	if (strncmp (buffer, NAUTILUS_KEY, strlen (NAUTILUS_KEY)) != 0)
+		return FALSE;
+
+	p = buffer + strlen (NAUTILUS_KEY);
+	
+	if (strncmp (p, NAUTILUS_HOME_KEY, strlen (NAUTILUS_HOME_KEY)) == 0)
+		return TRUE;
+
+	if (strncmp (p, NAUTILUS_TRASH_KEY, strlen (NAUTILUS_TRASH_KEY)) == 0)
+		return TRUE;
+	
+	if (strncmp (p, NAUTILUS_MOUNT_KEY, strlen (NAUTILUS_MOUNT_KEY)) == 0)
+		return TRUE;
+
+	return FALSE;
+}
 
 /* Reloads the desktop icons efficiently.  If there are "new" files for which no
  * icons have been created, then icons for them will be created started at the
@@ -614,14 +665,13 @@ desktop_reload_icons (int user_pos, int xpos, int ypos)
 	char *full_name;
 	int have_pos, x, y, size;
 	DesktopIconInfo *dii;
-	GSList *need_position_list, *sl, *drop_grid_list, *drop_gl_copy;
+	GSList *need_position_list, *sl, *drop_grid_list = NULL, *drop_gl_copy = NULL;
 	GList *all_icons, *l;
 	char *desktop_url, *caption;
 	const char *mime;
 	int orig_xpos, orig_ypos;
 	guint need_position_list_length;
 	static int first_reload = TRUE;
-	file_and_url_t *fau;
 
 	dir = mc_opendir (desktop_directory);
 	if (!dir) {
@@ -632,6 +682,18 @@ desktop_reload_icons (int user_pos, int xpos, int ypos)
 		return;
 	}
 
+	/*
+	 * Save the last time we scanned the directory
+	 */
+	{
+		struct stat buf;
+		
+		if (stat (desktop_directory, &buf) != -1)
+			desktop_dir_modify_time = buf.st_ctime;
+		else
+			desktop_dir_modify_time = time (NULL);
+	}
+	
 	gnome_metadata_lock ();
 
 	/* Read the directory.  For each file for which we do have an existing
@@ -651,6 +713,9 @@ desktop_reload_icons (int user_pos, int xpos, int ypos)
 			&& dirent->d_name[2] == 0))
 			continue;
 
+		if (should_skip_nautilus_file (dirent->d_name))
+			continue;
+		    
 		l = icon_exists_in_list (all_icons, dirent->d_name);
 		if (l) {
 			GdkImlibImage *im;
@@ -2414,6 +2479,25 @@ create_layout_info (void)
 	layout_slots = g_new0 (struct layout_slot, layout_cols * layout_rows);
 }
 
+/*
+ * Rename old Trash directory if found
+ */
+static void
+migrate_init (void)
+{
+	struct stat buf;
+	
+	char *old_trash_dir = g_concat_dir_and_file (desktop_directory, "Trash");
+	if (stat (old_trash_dir, &buf) == 0 && S_ISDIR (buf.st_mode)){
+		char *new_trash_dir = g_concat_dir_and_file (desktop_directory, "Trash.gmc");
+		
+		rename (old_trash_dir, new_trash_dir);
+		gnome_metadata_rename (old_trash_dir, new_trash_dir);
+		g_free (new_trash_dir);
+	}
+	g_free (old_trash_dir);
+}
+
 /*
  * Check that the user's desktop directory exists, and if not, create the
  * default desktop setup.
@@ -2436,6 +2520,7 @@ create_desktop_dir (void)
 		gmount_setup_devices ();
 		gprint_setup_devices ();
 	}
+	migrate_init ();
 }
 
 /* Property placed on target windows */
@@ -3405,6 +3490,29 @@ setup_desktop_clicks (void)
 	gdk_bitmap_unref (stipple);
 }
 
+static gboolean
+do_rescan (gpointer data)
+{
+	struct stat buf;
+	
+	if (stat (desktop_directory, &buf) == -1)
+		return TRUE;
+
+	if (buf.st_ctime == desktop_dir_modify_time)
+		return TRUE;
+
+	desktop_reload_icons (FALSE, 0, 0);
+	
+	return TRUE;
+}
+
+#define RESCAN_TIMEOUT 4000
+
+static void
+setup_desktop_reload_monitor (void)
+{
+	gtk_timeout_add (RESCAN_TIMEOUT, do_rescan, NULL);
+}
 
 /**
  * desktop_init
@@ -3432,6 +3540,9 @@ desktop_init (void)
 
 	setup_desktop_dnd ();
 	setup_desktop_clicks ();
+
+	/* Setup reloading */
+	setup_desktop_reload_monitor ();
 }
 
 /**
