@@ -4,7 +4,7 @@
 
    Authors: 1996, 1997 Paul Sheer
 
-   $Id: editcmd.c,v 1.31 2001/02/26 19:51:56 proskin Exp $
+   $Id: editcmd.c,v 1.32 2001/04/06 21:48:11 proskin Exp $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -389,15 +389,15 @@ void menu_save_mode_cmd (void)
     static QuickWidget widgets[] =
     {
 	{quick_button, 18, DLG_X, 7, DLG_Y, N_("&Cancel"), 0,
-	 B_CANCEL, 0, 0, XV_WLAY_DONTCARE, "c"},
+	 B_CANCEL, 0, 0, "c"},
 	{quick_button, 6, DLG_X, 7, DLG_Y, N_("&Ok"), 0,
-	 B_ENTER, 0, 0, XV_WLAY_DONTCARE, "o"},
+	 B_ENTER, 0, 0, "o"},
 	{quick_input, 23, DLG_X, 5, DLG_Y, 0, 9,
-	 0, 0, &str_result, XV_WLAY_DONTCARE, "i"},
+	 0, 0, &str_result, "i"},
 	{quick_label, 22, DLG_X, 4, DLG_Y, N_("Extension:"), 0,
-	 0, 0, 0, XV_WLAY_DONTCARE, "savemext"},
+	 0, 0, 0, "savemext"},
 	{quick_radio, 4, DLG_X, 3, DLG_Y, "", 3,
-	 0, &save_mode_new, str, XV_WLAY_DONTCARE, "t"},
+	 0, &save_mode_new, str, "t"},
 	{0}};
     static QuickDialog dialog =
     {DLG_X, DLG_Y, -1, -1, N_(" Edit Save Mode "), "[Edit Save Mode]",
@@ -1189,17 +1189,17 @@ int edit_replace_prompt (WEdit * edit, char *replace_text, int xpos, int ypos)
     QuickWidget quick_widgets[] =
     {
 	{quick_button, 63, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("&Cancel"),
-	 0, B_CANCEL, 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, B_CANCEL, 0, 0, NULL},
 	{quick_button, 50, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("o&Ne"),
-	 0, B_REPLACE_ONE, 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, B_REPLACE_ONE, 0, 0, NULL},
 	{quick_button, 37, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("al&L"),
-	 0, B_REPLACE_ALL, 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, B_REPLACE_ALL, 0, 0, NULL},
 	{quick_button, 21, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("&Skip"),
-	 0, B_SKIP_REPLACE, 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, B_SKIP_REPLACE, 0, 0, NULL},
 	{quick_button, 4, CONFIRM_DLG_WIDTH, 3, CONFIRM_DLG_HEIGTH, N_ ("&Replace"),
-	 0, B_ENTER, 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, B_ENTER, 0, 0, NULL},
 	{quick_label, 2, CONFIRM_DLG_WIDTH, 2, CONFIRM_DLG_HEIGTH, 0,
-	 0, 0, 0, 0, XV_WLAY_DONTCARE, 0},
+	 0, 0, 0, 0, 0},
 	{0}};
 
     quick_widgets[5].text = catstrs (_ (" Replace with: "), replace_text, 0);
@@ -1239,35 +1239,35 @@ void edit_replace_dialog (WEdit * edit, char **search_text, char **replace_text,
     QuickWidget quick_widgets[] =
     {
 	{quick_button, 6, 10, 12, REPLACE_DLG_HEIGHT, N_("&Cancel"), 0, B_CANCEL, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 	{quick_button, 2, 10, 12, REPLACE_DLG_HEIGHT, N_("&Ok"), 0, B_ENTER, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 	{quick_checkbox, 33, REPLACE_DLG_WIDTH, 11, REPLACE_DLG_HEIGHT, N_("scanf &Expression"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 33, REPLACE_DLG_WIDTH, 10, REPLACE_DLG_HEIGHT, N_("replace &All"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 33, REPLACE_DLG_WIDTH, 9, REPLACE_DLG_HEIGHT, N_("pr&Ompt on replace"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, REPLACE_DLG_WIDTH, 11, REPLACE_DLG_HEIGHT, N_("&Backwards"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, REPLACE_DLG_WIDTH, 10, REPLACE_DLG_HEIGHT, N_("&Regular expression"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, REPLACE_DLG_WIDTH, 9, REPLACE_DLG_HEIGHT, N_("&Whole words only"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, REPLACE_DLG_WIDTH, 8, REPLACE_DLG_HEIGHT, N_("case &Sensitive"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_input,    3, REPLACE_DLG_WIDTH, 7, REPLACE_DLG_HEIGHT, "", 52, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "edit-argord"},
+	 0, "edit-argord"},
 	{quick_label, 2, REPLACE_DLG_WIDTH, 6, REPLACE_DLG_HEIGHT, N_(" Enter replacement argument order eg. 3,2,1,4 "), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, 0},
+	 0, 0, 0},
 	{quick_input, 3, REPLACE_DLG_WIDTH, 5, REPLACE_DLG_HEIGHT, "", 52, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "edit-replace"},
+	 0, "edit-replace"},
 	{quick_label, 2, REPLACE_DLG_WIDTH, 4, REPLACE_DLG_HEIGHT, N_(" Enter replacement string:"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{quick_input, 3, REPLACE_DLG_WIDTH, 3, REPLACE_DLG_HEIGHT, "", 52, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "edit-search"},
+	 0, "edit-search"},
 	{quick_label, 2, REPLACE_DLG_WIDTH, 2, REPLACE_DLG_HEIGHT, N_(" Enter search string:"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{0}};
 
     quick_widgets[2].result = &treplace_scanf;
@@ -1324,23 +1324,23 @@ void edit_search_dialog (WEdit * edit, char **search_text)
     QuickWidget quick_widgets[] =
     {
 	{quick_button, 6, 10, 7, SEARCH_DLG_HEIGHT, N_("&Cancel"), 0, B_CANCEL, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 	{quick_button, 2, 10, 7, SEARCH_DLG_HEIGHT, N_("&Ok"), 0, B_ENTER, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 	{quick_checkbox, 33, SEARCH_DLG_WIDTH, 6, SEARCH_DLG_HEIGHT, N_("scanf &Expression"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL },
+	 0, 0, NULL },
 	{quick_checkbox, 33, SEARCH_DLG_WIDTH, 5, SEARCH_DLG_HEIGHT, N_("&Backwards"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, SEARCH_DLG_WIDTH, 6, SEARCH_DLG_HEIGHT, N_("&Regular expression"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, SEARCH_DLG_WIDTH, 5, SEARCH_DLG_HEIGHT, N_("&Whole words only"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_checkbox, 4, SEARCH_DLG_WIDTH, 4, SEARCH_DLG_HEIGHT, N_("case &Sensitive"), 0, 0,
-	 0, 0, XV_WLAY_DONTCARE, NULL},
+	 0, 0, NULL},
 	{quick_input, 3, SEARCH_DLG_WIDTH, 3, SEARCH_DLG_HEIGHT, "", 52, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "edit-search"},
+	 0, "edit-search"},
 	{quick_label, 2, SEARCH_DLG_WIDTH, 2, SEARCH_DLG_HEIGHT, N_(" Enter search string:"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{0}};
 
     quick_widgets[2].result = &treplace_scanf;
@@ -3019,23 +3019,23 @@ void edit_mail_dialog (WEdit * edit)
     QuickWidget quick_widgets[] =
     {
 	{quick_button, 6, 10, 9, MAIL_DLG_HEIGHT, N_("&Cancel"), 0, B_CANCEL, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 	{quick_button, 2, 10, 9, MAIL_DLG_HEIGHT, N_("&Ok"), 0, B_ENTER, 0,
-	 0, XV_WLAY_DONTCARE, NULL},
+	 0, NULL},
 	{quick_input, 3, 50, 8, MAIL_DLG_HEIGHT, "", 44, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "mail-dlg-input"},
+	 0, "mail-dlg-input"},
 	{quick_label, 2, 50, 7, MAIL_DLG_HEIGHT, N_(" Copies to"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{quick_input, 3, 50, 6, MAIL_DLG_HEIGHT, "", 44, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "mail-dlg-input-2"},
+	 0, "mail-dlg-input-2"},
 	{quick_label, 2, 50, 5, MAIL_DLG_HEIGHT, N_(" Subject"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{quick_input, 3, 50, 4, MAIL_DLG_HEIGHT, "", 44, 0, 0,
-	 0, XV_WLAY_BELOWCLOSE, "mail-dlg-input-3"},
+	 0, "mail-dlg-input-3"},
 	{quick_label, 2, 50, 3, MAIL_DLG_HEIGHT, N_(" To"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{quick_label, 2, 50, 2, MAIL_DLG_HEIGHT, N_(" mail -s <subject> -c <cc> <to>"), 0, 0, 0,
-	 0, XV_WLAY_DONTCARE, 0},
+	 0, 0},
 	{0}};
 
     quick_widgets[2].str_result = &tmail_cc;
