@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #define _GTK_EDIT_C
 
@@ -31,7 +31,9 @@
 #include "gtk/gtkselection.h"
 #include "gtk/gtksignal.h"
 #include "edit.h"
+#if ! defined (MIDNIGHT) && ! defined (GTK)
 #include "mousemark.h"
+#endif
 
 #define EDIT_BORDER_ROOM         1
 #define MIN_EDIT_WIDTH_LINES     20
