@@ -4,6 +4,8 @@
 
    Authors: 1998 Paul Sheer
 
+   $Id: syntax.c,v 1.16 2000/09/07 17:45:28 andrew Exp $
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
@@ -1156,11 +1158,8 @@ void edit_free_syntax_rules (WEdit * edit)
 	syntax_free (edit->rules[i]->keyword_first_chars);
 	syntax_free (edit->rules[i]);
     }
-    for (;;) {
-	struct _syntax_marker *s;
-	if (!edit->syntax_marker)
-	    break;
-	s = edit->syntax_marker->next;
+    while (edit->syntax_marker) {
+	struct _syntax_marker *s = edit->syntax_marker->next;
 	syntax_free (edit->syntax_marker);
 	edit->syntax_marker = s;
     }
@@ -1169,7 +1168,7 @@ void edit_free_syntax_rules (WEdit * edit)
 
 #define CURRENT_SYNTAX_RULES_VERSION "62"
 
-char *syntax_text[] = {
+static const char * const syntax_text[] = {
 "# syntax rules version " CURRENT_SYNTAX_RULES_VERSION,
 "# (after the slash is a Cooledit color, 0-26 or any of the X colors in rgb.txt)",
 "# black",
@@ -1253,7 +1252,7 @@ char *syntax_text[] = {
 "file .\\*ChangeLog$ GNU\\sDistribution\\sChangeLog\\sFile",
 "include changelog.syntax",
 "",
-"file .\\*Makefile[\\\\\\.a-z]\\*$ Makefile",
+"file .\\*[Mm]akefile[\\\\\\.a-z]\\*$ Makefile",
 "include makefile.syntax",
 "",
 "file Don_t_match_me Mail\\sfolder ^From\\s",
@@ -1346,7 +1345,8 @@ FILE *upgrade_syntax_file (char *syntax_file)
     char line[80];
     f = fopen (syntax_file, "r");
     if (!f) {
-	char **syntax_line;
+	const char * const *syntax_line;
+      rewrite_rule_file:
 	f = fopen (syntax_file, "w");
 	if (!f)
 	    return 0;
@@ -1363,6 +1363,7 @@ FILE *upgrade_syntax_file (char *syntax_file)
     if (atoi (p) < atoi (CURRENT_SYNTAX_RULES_VERSION)) {
 	char s[1024];
       rename_rule_file:
+	fclose (f);
 	strcpy (s, syntax_file);
 	strcat (s, ".OLD");
 	unlink (s);
@@ -1373,7 +1374,7 @@ FILE *upgrade_syntax_file (char *syntax_file)
 #else
 	CMessageDialog (0, 20, 20, 0,_(" Load Syntax Rules "), _(" Your syntax rule file is outdated \n A new rule file is being installed. \n Your old rule file has been saved with a .OLD extension. ")); 
 #endif
-	return upgrade_syntax_file (syntax_file);
+	goto rewrite_rule_file;
     }
     rewind (f);
     return f;
