@@ -16,7 +16,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
 #ifdef __os2__
@@ -77,6 +77,9 @@
 #include "setup.h"
 #include "x.h"
 #include "profile.h"
+#ifndef HAVE_X
+#include "textconf.h"
+#endif
 
 #define MIDNIGHT
 #include "../vfs/vfs.h"
@@ -339,9 +342,13 @@ do_edit (const char *what)
 
 void edit_cmd (WPanel *panel)
 {
+#ifndef HAVE_GNOME
     panel = get_a_panel(panel);
     if (!regex_command (selection (panel)->fname, "Edit", NULL, 0))
         do_edit (selection (panel)->fname);
+#else
+    gmc_edit (selection (panel)->fname);
+#endif
 }
 
 void edit_cmd_new (WPanel *panel)
@@ -626,6 +633,7 @@ static int check_for_default(char *default_file, char *file)
     return 0;
 }
 
+#ifndef HAVE_GNOME
 void ext_cmd (void)
 {
     char *buffer;
@@ -651,6 +659,7 @@ void ext_cmd (void)
    g_free (extdir);
    flush_extension_file ();
 }
+#endif /* !HAVE_GNOME */
 
 /* where  = 0 - do edit a file menu for mc */
 /* where  = 1 - do edit a file menu for cool edit */
@@ -949,9 +958,9 @@ view_other_cmd (void)
 #ifndef HAVE_X
 	keypad(stdscr, FALSE);
 	endwin ();
-#endif
 	if (!status_using_ncurses)
 	    do_exit_ca_mode ();
+#endif
 	mc_raw_mode ();
 	if (console_flag)
 	    restore_console ();
@@ -976,10 +985,10 @@ view_other_cmd (void)
 	if (console_flag)
 	    handle_console (CONSOLE_SAVE);
 
+#ifndef HAVE_X	
 	if (!status_using_ncurses)
 	    do_enter_ca_mode ();
 
-#ifndef HAVE_X	
 	reset_prog_mode ();
 	keypad(stdscr, TRUE);
 	if (use_mouse_p)
@@ -1200,7 +1209,7 @@ void other_symlink_cmd (void)
 
 void help_cmd (void)
 {
-   char *hlpfile = concat_dir_and_file (mc_home, "mc.hlp");
+   char *hlpfile = concat_dir_and_file (mc_home, _("mc.hlp"));
    interactive_display (hlpfile, "[main]");
    g_free (hlpfile);
 }
