@@ -19,7 +19,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* This code does _not_ need to be setuid root. However, it needs
    read/write access to /dev/vcsa* (which is priviledged
@@ -42,6 +42,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>	/* For isdigit() */
+#include <string.h>
 typedef struct WINDOW WINDOW;
 #include "cons.saver.h"
 
@@ -116,39 +117,43 @@ int check_file (char *filename, int check_console, char **msg)
     if (fd == -1)
 	return -1;
     
-    if (fstat (fd, &stat_buf) == -1)
-	return -1;
+    do {
+	if (fstat (fd, &stat_buf) == -1)
+	    break;
 
-    /* Must be character device */
-    if (!S_ISCHR (stat_buf.st_mode)){
-	*msg = "Not a character device";
-	return -1;
-    }
+	/* Must be character device */
+	if (!S_ISCHR (stat_buf.st_mode)){
+	    *msg = "Not a character device";
+	    break;
+	}
 
 #ifdef DEBUG
-    fprintf (stderr, "Device: %x\n", stat_buf.st_rdev);
+	fprintf (stderr, "Device: %x\n", stat_buf.st_rdev);
 #endif
-    if (check_console){
-	/* Second time: must be console */
-	if ((stat_buf.st_rdev & 0xff00) != 0x0400){
-	    *msg = "Not a console";
-	    return -1;
+	if (check_console){
+	    /* Second time: must be console */
+	    if ((stat_buf.st_rdev & 0xff00) != 0x0400){
+		*msg = "Not a console";
+		break;
+	    }
+
+	    if ((stat_buf.st_rdev & 0x00ff) > 63){
+		*msg = "Minor device number too big";
+		break;
+	    }
+
+	    /* Must be owned by the user */
+	    if (stat_buf.st_uid != getuid ()){
+		*msg = "Not a owner";
+		break;
+	    }
 	}
-    
-	if ((stat_buf.st_rdev & 0x00ff) > 63){
-	    *msg = "Minor device number too big";
-	    return -1;
-	}
-	
-	/* Must be owned by the user */
-	if (stat_buf.st_uid != getuid ()){
-	    *msg = "Not a owner";
-	    return -1;
-	}
-    }
-    
     /* Everything seems to be okay */
-    return fd;
+	return fd;
+    } while (0);
+
+    close (fd);
+    return -1;
 }
 
 /* Detect console */
