@@ -13,12 +13,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Events received by clients of this library have their coordinates 0 */
 /* based */
 
-/* "$Id: mouse.c,v 1.4 1999/01/27 01:09:19 timur Exp $" */
+/* "$Id: mouse.c,v 1.5 2000/08/22 22:50:15 proskin Exp $" */
 
 #include <config.h>
 #include <sys/types.h>
