@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    This module has been converted to be a widget.
 
@@ -59,7 +59,7 @@ int tree_navigation_flag;
 static int tree_callback (Dlg_head *h, WTree *tree, int msg, int par);
 #define tcallback (callback_fn) tree_callback
 
-/* "$Id: tree.c,v 1.22 1999/09/14 00:31:35 unammx Exp $" */
+/* "$Id: tree.c,v 1.24 2001/01/08 18:21:37 bansz Exp $" */
 
 static tree_entry *back_ptr (tree_entry *ptr, int *count)
 {
@@ -651,7 +651,7 @@ void tree_copy (WTree *tree, char *default_dest)
 
 static void tree_help_cmd (void)
 {
-    char *hlpfile = concat_dir_and_file (mc_home, "mc.hlp");
+    char *hlpfile = concat_dir_and_file (mc_home, _("mc.hlp"));
     interactive_display (hlpfile,  "[Directory Tree]");
     g_free (hlpfile);
 }
