@@ -6,7 +6,7 @@
               Andrej Borsenkow
 	      Norbert Warmuth
    
-   $Id: mcfs.c,v 1.16 1999/12/16 12:55:16 pavel Exp $
+   $Id: mcfs.c,v 1.19 2001/03/08 01:04:58 proskin Exp $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
@@ -20,7 +20,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* Namespace: exports mcfs_vfs_ops, tcp_invalidate_socket */
 
@@ -38,10 +38,6 @@
 #include <sys/socket.h>		/* AF_INET */
 #include <netinet/in.h>		/* struct in_addr */
 #include <arpa/inet.h>
-#ifdef SCO_FLAVOR
-#include <sys/timeb.h>	/* alex: for struct timeb definition */
-#endif /* SCO_FLAVOR */
-#include <time.h>
 
 #ifdef USE_TERMNET
 #include <termnet.h>
@@ -57,7 +53,6 @@
 #define MCFS_MAX_CONNECTIONS 32
 #define mcserver_port 9876
 
-static mcfs_open_connections = 0;
 static struct _mcfs_connection {
     char *host;
     char *user;
@@ -305,6 +300,7 @@ static mcfs_connection *mcfs_get_free_bucket ()
 /* Returns a connected socket to host */
 static mcfs_connection *mcfs_open_link (char *host, char *user, int *port, char *netrcpass)
 {
+    static int mcfs_open_connections = 0;
     int i, sock, version;
     mcfs_connection *bucket;
 
